task fastp {

	Array[File] sample_info
	String sample_name
	String outdir

	command {
		fastp -i ${sample_info[1]} -I ${sample_info[2]} -o ${outdir + "/" + sample_name + ".R1.fastq"} -O ${outdir + "/" + sample_name + ".R2.fastq"} -n 15 -q 20 -u 50 -l 50 --adapter_sequence AGATCGGAAGAGCACACGTCTGAACTCCAGTC --adapter_sequence_r2 AGATCGGAAGAGCGTCGTGTAGGGAAAGAGTGT -G -j ${outdir + "/" + sample_name + ".json"} -h ${outdir + "/" + sample_name + ".html"}
	}

	output {
		File reado = "${outdir}/${sample_name}.R1.fastq"
		File readt = "${outdir}/${sample_name}.R2.fastq"
	}

	runtime{
		docker:"fastp:latest"
		cpu:"5"
		memory:"5G"
	}
}

task bwa_mem {

	File reado
	File readt
	String sample_name
	String Ref_file
	String outdir

	command {
		/BioBin/bwa/bwa mem -R '@RG\tID:1\tLB:lib1\tPL:ILLUMINA\tSM:${sample_name}\tPU:unit1' -k 2 -t 18 ${Ref_file} ${reado} ${readt} > ${outdir + "/" + sample_name + ".sam"}
	}

	output {
		File sam = "${outdir}/${sample_name}.sam"
	}

	runtime{
		docker:"bwa:base"
		cpu:"18"
		memory:"80G"
	}
}

task samtobam {

	File sam

	command {
		/BioBin/samtools/samtools view -bS ${sam} -o ${sam}.bam
	}

	output {
		File outbam = "${sam}.bam"
	}

	runtime{
		docker:"bwa:base"
		cpu:"1.5"
		memory:"4G"
  }
}

task sortbam {

	File bam

	command {
		/BioBin/samtools/samtools sort ${bam} -o ${bam}.sorted.bam
	}

	output {
		File outbam = "${bam}.sorted.bam"
	}

	runtime{
		docker:"bwa:base"
		cpu:"2"
		memory:"8G"
	}
}

task markdup {

	File bam

	command {
		java -jar /gatk/gatk.jar MarkDuplicates --INPUT ${bam} --METRICS_FILE $output.metrics --OUTPUT ${bam}.dup.bam
	}

	output {
		File outbam = "${bam}.dup.bam"
	}

	runtime{
		docker:"gatk4:latest"
		cpu:"10"
		memory:"30G"
	}
}

task bamindex {

	File bam

	command {
		/BioBin/samtools/samtools index ${bam}
	}

	output {
		File outbam = "${bam}"
	}

	runtime{
		docker:"bwa:base"
		cpu:"2"
		memory:"8G"
	}
}

task mkdir {

	String dirName

	command {
		mkdir ${dirName}
	}

	output {
		File path = "${dirName}"
	}
}

task mkdir_module {

	String dirName1
	String dirName2

	command {
		mkdir ${dirName1 + "/" + dirName2}
	}

	output {
		File path = "${dirName1}/${dirName2}"
	}
}
